@@ -4,9 +4,9 @@ from pubhelper.func import *
 from pubhelper.debug import *
 from pubhelper.retry_wraps import *
 from pubhelper.simple_cache import *
-from pubhelper.request_base import *
 from pubhelper.params_check import *
 from pubhelper.simple_priority_queue import *
+from pubhelper.concurrency import *
 
 logging.basicConfig(
     level=logging.INFO,
