@@ -31,11 +31,11 @@ def with_log(fn=None, *, logger=None):
         def _inner(*args, **kwargs):
             logger.debug(
                 f'func({f.__name__}) running(args={args}, kwargs={kwargs})')
-            result = f(*args, **kwargs)
-            if isinstance(result, Exception):
-                logger.error(f'func({f.__name__}) error: {result}')
-            else:
+            try:
+                result = f(*args, **kwargs)
                 logger.debug(f'func({f.__name__}) result: {result}')
+            except Exception as e:
+                return logger.error(f'func({f.__name__}) error: {e}')
             return result
 
         return _inner
