@@ -2,7 +2,6 @@ import functools
 import hashlib
 import random
 import string
-from IPy import intToIp
 from typing import Union
 
 
@@ -23,8 +22,4 @@ def ip_2_int(ip: str):
     return functools.reduce(lambda x, y: (x << 8) + y, map(int, ip.split('.')))
 
 
-def int_2_ip(ip: int):
-    return intToIp(ip, 4)
-
-
-__all__ = ('rdm_str', 'md5', 'ip_2_int', 'int_2_ip')
+__all__ = ('rdm_str', 'md5', 'ip_2_int')
