@@ -14,7 +14,7 @@ def params_check(fn=None, *, required: list = None, optional: list = None, debug
     def _check_optional(func_name: str, **kwargs):
         for item in (optional or []):
             if item not in kwargs:
-                logger.debug(f'[{func_name}] optional param({item}) not found')
+                logger.warning(f'[{func_name}] optional param({item}) not found')
 
     def inner(f):
         @functools.wraps(f)
