@@ -10,14 +10,14 @@ def retry_wraps(
         fn: Callable = None,
         *,
         retry_times: int = 0,
-        is_debug: bool = True,
+        debug: bool = True,
         retry_interval: int = 1,
         onretry: Callable = None,
         finally_call: Callable = None,
         default: Any = '__no_default__',
 ):
     logger = logging.getLogger('__retry_wraps__')
-    is_debug and logger.setLevel(logging.DEBUG)
+    debug and logger.setLevel(logging.DEBUG)
 
     def sync_retry(f, times, *args, **kwargs):
         try:
