@@ -5,23 +5,24 @@ from weakref import WeakValueDictionary
 
 class CachedManager(WeakValueDictionary):
     """
-    局部变量，新建缓存，当局部变量被销毁时，缓存也会被清除
+    永久缓存，需要手动删除
     """
-    thread_lock: threading.Lock = threading.Lock()
+    cache_lock: threading.Lock = threading.Lock()
 
     def get(self, key: Any) -> Optional[Any]:
-        with self.thread_lock:
+        with self.cache_lock:
             if not super(CachedManager, self).get(key):
-                data = CacheItem()
+                data = Cache()
                 self.__setitem__(key, data)
             return super(CachedManager, self).get(key)
 
 
-class CacheItem(dict):
-    m: CachedManager = CachedManager()
+class Cache(dict):
+    _m: CachedManager = CachedManager()
 
-    def set(self, **kwargs):
-        [self.__setitem__(k, v) for k, v in kwargs.items()]
+    @classmethod
+    def fetch(cls, key: Any):
+        return cls._m.get(key)
 
 
-__all__ = ('CacheItem',)
+__all__ = ('Cache',)
